==> src_release_V2.10.tar.gz: dserver/system/xdr/src/grp_xdr.c <==
static char RcsId[] =
"@(#)$Header: grp_xdr.c,v 5.21 2001/11/12 10:01:36 goetz Rel $";

/*+*******************************************************************

 File:          grp_xdr.c

 Project:       Device Servers with sun-rpc

 Description:   xdr_routines for  data types.

 Author(s):	Jens Meyer

 Original:	July 1992

$Revision: 5.21 $
$Date: 2001/11/12 10:01:36 $

$Author: goetz $

$Log:	grp_xdr.c,v $
 * Revision 5.21  2001/11/12  10:01:36  10:01:36  goetz (Andy Goetz)
 * updated C port for Windows 95/98/NT using Visual C++ 6
 * 
Revision 5.20  2001/01/08 12:17:35  goetz
added patch by B.Pedersen to support querying events

Revision 5.19  2000/10/02 12:08:45  goetz
removed stderr from api_xdr.c

Revision 5.18  1999/07/08 14:10:46  goetz
changed _LPfd_set type for Linux in macros.h

Revision 5.17  1998/05/25 17:59:46  klotz
fixed C++ prototypes in api_xdr.h

Revision 5.16  1998/04/29 10:24:08  goetz
macros.h - added __STDCPP__ for HP C++ compiler (aCC)

 * Revision 5.15  97/12/01  15:16:13  15:16:13  klotz (W.D. Klotz)
 * WIN_NT_95_released_NOV_97
 * 
 * Revision 4.34  97/01/30  13:58:40  13:58:40  goetz (Andy Goetz)
 * removed dev_printdebug() from DevXdrKernel.h
 * 
 * Revision 4.33  97/01/09  10:08:46  10:08:46  goetz (Andy Goetz)
 * (xdrproc_t) castings added to maxe_xdr, ram_xdr, thc_xdr, seism_xdr
 * 
 * Revision 4.32  97/01/08  16:48:35  16:48:35  goetz (Andy Goetz)
 * Ported to Linux (2.0.9)
 * 
Revision 4.31  1996/11/18 17:28:51  goetz
Check

 * Revision 4.28  96/10/21  16:22:30  16:22:30  taurel (E.Taurel)
 * Check_in_after_port_to_OS9/ISP_2.1_and_OS9/RPC1.4
 * 
 * Revision 4.27  96/09/17  16:40:02  16:40:02  klotz (W.D. Klotz)
 * WD Klotz: tested NT build  
 * 
 * Revision 4.26  96/07/19  10:01:04  10:01:04  taurel (E.Taurel)
 * Some_change_in_macros.h_for_the_API_port_to_OS-9_Ultra_C++
 * 
 * Revision 4.25  96/06/07  16:23:09  16:23:09  meyer (J.Meyer)
 * Corrected_elif_to_else_in_macros.h
 * 
 * Revision 4.24  96/06/05  15:01:44  15:01:44  meyer (J.Meyer)
 * Corrected_macros.h
 * 
 * Revision 4.23  96/06/03  13:10:22  13:10:22  meyer (J.Meyer)
 * Cleaned-up_MSDOS_and_added_porting_options_for_Windows_NT.
 * 
 * Revision 4.22  96/05/23  11:07:30  11:07:30  taurel (E.Taurel)
 * Added_some_definitions_for_C++_in_API_xdr.h_file
 * 
 * Revision 4.21  96/05/06  18:37:40  18:37:40  meyer (J.Meyer)
 * Fortran_compatibility_for:_dev_xdr.h,macros.h,maxe_xdr.h
 * 
 * Revision 4.20  96/02/27  13:31:40  13:31:40  meyer (J.Meyer)
 * Deleted_Cross_References_To_DSAPI_Library
 * 
 * Revision 4.19  96/01/11  17:40:25  17:40:25  meyer (Jens Meyer)
 * Added_#define_PORTMAP_to_macros.h.
 * 
 * Revision 4.18  95/12/21  10:33:38  10:33:38  meyer (Jens Meyer)
 * Corrected length calculation for D_VAR_MSTATARR.
 * 
 * Revision 4.17  95/08/02  16:05:17  16:05:17  meyer (Jens Meyer)
 * Corrected DevXdrKernel.h after C++ implementation.
 * 
 * Revision 4.15  95/03/02  10:28:01  10:28:01  meyer (Jens Meyer)
 * Added D_VAR_SFRPARR type to the kernel.
 * 
 * Revision 4.14  95/02/20  09:56:52  09:56:52  meyer (Jens Meyer)
 * Passed the compilers for HPUX, SUNOS and UCC after the first windows check in.
 * 
 * Revision 4.13  95/02/10  17:19:08  17:19:08  meyer (Jens Meyer)
 * Deleted
 * 
 * Revision 4.12  95/02/01  14:26:51  14:26:51  klotz (W.D. Klotz)
 * WDK: first successfull compile of dbase, api, xdr on WIN16/3.1
 * 
 * Revision 4.11  95/01/03  13:19:29  13:19:29  meyer (Jens Meyer)
 * Repared bug in dev_cmd_query() for version 3!
 * 
 * Revision 4.10  94/12/08  15:24:59  15:24:59  meyer (Jens Meyer)
 * Changed _manager_data in API_xdr and added old version to API_xdr_vers3.
 * 
 * Revision 4.9  94/11/28  17:04:21  17:04:21  meyer (Jens Meyer)
 * Data types for compatibility with library version 3.x
 * 
 * Revision 4.8  94/08/16  16:59:38  16:59:38  meyer (Jens Meyer)
 * Corrected error in ws_xdr.h
 * 
 * Revision 4.7  94/08/16  16:34:33  16:34:33  meyer (Jens Meyer)
 * Added define for MAX_RESOURCE_FIELD_LENGTH to macros.h
 * 
 * Revision 4.6  94/08/12  15:07:49  15:07:49  meyer (Jens Meyer)
 * Added valriable arguments to all API RPC structures.
 * 
 * Revision 4.5  94/07/20  18:15:48  18:15:48  meyer (Jens Meyer)
 * Changed include files in macros.h!
 * 
 * Revision 4.4  94/07/20  08:55:43  08:55:43  meyer (Jens Meyer)
 * All XDR functions with prototypes!
 * 
 * Revision 4.3  94/07/18  18:50:57  18:50:57  meyer (Jens Meyer)
 * Had to change macros.h, because #define must be in the first column!
 * 
 * Revision 4.2  94/07/18  18:22:09  18:22:09  meyer (Jens Meyer)
 * First test with PC macros for the XDR kernel.
 * 
 * Revision 4.1  94/05/02  10:50:51  10:50:51  meyer (Jens Meyer)
 * For Security System without connection count.
 * 
 * Revision 4.0  94/03/14  18:17:36  18:17:36  meyer (Jens Meyer)
 * Library version with Security System.
 * 
 * Revision 3.50  94/03/12  14:36:29  14:36:29  meyer (Jens Meyer)
 * Changed API xdr structures for security.
 * 
 * Revision 3.35  94/03/03  10:52:14  10:52:14  taurel (Emmanuel TAUREL)
 * Added unsigned long array type in the XDRkernel
 * 
 * Revision 3.34  94/03/03  10:29:05  10:29:05  taurel (Emmanuel TAUREL)
 * Added the unsigned long array type in
 * XDR kernel (LC and ET).
 * 
 * Revision 3.33  94/01/12  16:34:29  16:34:29  meyer (Jens Meyer)
 * Global XDR type array for data collector access
 * 
 * Revision 3.31  93/12/02  09:39:04  09:39:04  meyer (Jens Meyer)
 * New release with small XDR data type kernel.
 * 
 * Revision 1.1  93/11/16  17:27:52  17:27:52  meyer (Jens Meyer)
 * Initial revision
 * 

 Copyright (c) 1990 by European Synchrotron Radiation Facility,
		       Grenoble, France

*******************************************************************-*/


#include <dev_xdr.h>
#include <grp_xdr.h>



bool_t
xdr_Frame(xdrs, objp)
	XDR *xdrs;
	Frame *objp;
{
	if (!xdr_double(xdrs, &objp->value)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->output)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->pause)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_Frame(objp)
	Frame *objp;
{
        long  length = 0;

	length = length + xdr_length_DevDouble (&objp->value);
        length = length + xdr_length_DevShort (&objp->output);
        length = length + xdr_length_DevShort (&objp->pause);

        return (length);

}



bool_t
xdr_FramePair(xdrs, objp)
	XDR *xdrs;
	FramePair *objp;
{
	if (!xdr_Frame(xdrs, &objp->dead)) {
		return (FALSE);
	}
	if (!xdr_Frame(xdrs, &objp->live)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_FramePair(objp)
	FramePair *objp;
{
        long  length = 0;

        length = length + xdr_length_Frame (&objp->dead);
        length = length + xdr_length_Frame (&objp->live);

        return (length);

}




bool_t
xdr_DevGrpFramePair(xdrs, objp)
	XDR *xdrs;
	DevGrpFramePair *objp;
{
	if (!xdr_u_int(xdrs, &objp->nb_framepair)) {
		return (FALSE);
	}
	if (!xdr_FramePair(xdrs, &objp->framepair)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_DevGrpFramePair(objp)
	DevGrpFramePair *objp;
{
        long  length = 0;

        length = length + xdr_length_DevLong ((long*)&objp->nb_framepair);
        length = length + xdr_length_FramePair (&objp->framepair);

        return (length);

}



bool_t
xdr_DevGrpFramePairArray(xdrs, objp)
	XDR *xdrs;
	DevGrpFramePairArray *objp;
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->sequence, 
	    (u_int *)&objp->length, MAXU_INT, sizeof(DevGrpFramePair), 
	    (xdrproc_t)xdr_DevGrpFramePair)) {
		return (FALSE);
	}
	return (TRUE);
}


long
xdr_length_DevGrpFramePairArray(objp)
	DevGrpFramePairArray *objp;
{
        long    length = 0;

        /*
         *  four bytes for the number of array elements
         */

	length = length + xdr_length_DevLong ((long *)&objp->length);

        /*
         *  now calculate the length of the array
         */

        length = length + (objp->length *
                 xdr_length_DevGrpFramePair(&objp->sequence[0]) );

        return (length);
}

==> src_release_V2.12.tar.gz: dserver/system/xdr/src/grp_xdr.c <==
static char RcsId[] =
"@(#)$Header: /segfs/dserver/system/xdr/src/RCS/grp_xdr.c,v 5.22 2002/03/11 12:35:57 goetz Rel $";

/*+*******************************************************************

 File:          grp_xdr.c

 Project:       Device Servers with sun-rpc

 Description:   xdr_routines for  data types.

 Author(s):	Jens Meyer

 Original:	July 1992

$Revision: 5.22 $
$Date: 2002/03/11 12:35:57 $

$Author: goetz $

$Log: grp_xdr.c,v $
Revision 5.22  2002/03/11 12:35:57  goetz
added extern C prototype to VGC xdr routines for C++

Revision 5.21  2001/11/12 10:01:36  goetz
updated C port for Windows 95/98/NT using Visual C++ 6

Revision 5.20  2001/01/08 12:17:35  goetz
added patch by B.Pedersen to support querying events

Revision 5.19  2000/10/02 12:08:45  goetz
removed stderr from api_xdr.c

Revision 5.18  1999/07/08 14:10:46  goetz
changed _LPfd_set type for Linux in macros.h

Revision 5.17  1998/05/25 17:59:46  klotz
fixed C++ prototypes in api_xdr.h

Revision 5.16  1998/04/29 10:24:08  goetz
macros.h - added __STDCPP__ for HP C++ compiler (aCC)

 * Revision 5.15  97/12/01  15:16:13  15:16:13  klotz (W.D. Klotz)
 * WIN_NT_95_released_NOV_97
 * 
 * Revision 4.34  97/01/30  13:58:40  13:58:40  goetz (Andy Goetz)
 * removed dev_printdebug() from DevXdrKernel.h
 * 
 * Revision 4.33  97/01/09  10:08:46  10:08:46  goetz (Andy Goetz)
 * (xdrproc_t) castings added to maxe_xdr, ram_xdr, thc_xdr, seism_xdr
 * 
 * Revision 4.32  97/01/08  16:48:35  16:48:35  goetz (Andy Goetz)
 * Ported to Linux (2.0.9)
 * 
Revision 4.31  1996/11/18 17:28:51  goetz
Check

 * Revision 4.28  96/10/21  16:22:30  16:22:30  taurel (E.Taurel)
 * Check_in_after_port_to_OS9/ISP_2.1_and_OS9/RPC1.4
 * 
 * Revision 4.27  96/09/17  16:40:02  16:40:02  klotz (W.D. Klotz)
 * WD Klotz: tested NT build  
 * 
 * Revision 4.26  96/07/19  10:01:04  10:01:04  taurel (E.Taurel)
 * Some_change_in_macros.h_for_the_API_port_to_OS-9_Ultra_C++
 * 
 * Revision 4.25  96/06/07  16:23:09  16:23:09  meyer (J.Meyer)
 * Corrected_elif_to_else_in_macros.h
 * 
 * Revision 4.24  96/06/05  15:01:44  15:01:44  meyer (J.Meyer)
 * Corrected_macros.h
 * 
 * Revision 4.23  96/06/03  13:10:22  13:10:22  meyer (J.Meyer)
 * Cleaned-up_MSDOS_and_added_porting_options_for_Windows_NT.
 * 
 * Revision 4.22  96/05/23  11:07:30  11:07:30  taurel (E.Taurel)
 * Added_some_definitions_for_C++_in_API_xdr.h_file
 * 
 * Revision 4.21  96/05/06  18:37:40  18:37:40  meyer (J.Meyer)
 * Fortran_compatibility_for:_dev_xdr.h,macros.h,maxe_xdr.h
 * 
 * Revision 4.20  96/02/27  13:31:40  13:31:40  meyer (J.Meyer)
 * Deleted_Cross_References_To_DSAPI_Library
 * 
 * Revision 4.19  96/01/11  17:40:25  17:40:25  meyer (Jens Meyer)
 * Added_#define_PORTMAP_to_macros.h.
 * 
 * Revision 4.18  95/12/21  10:33:38  10:33:38  meyer (Jens Meyer)
 * Corrected length calculation for D_VAR_MSTATARR.
 * 
 * Revision 4.17  95/08/02  16:05:17  16:05:17  meyer (Jens Meyer)
 * Corrected DevXdrKernel.h after C++ implementation.
 * 
 * Revision 4.15  95/03/02  10:28:01  10:28:01  meyer (Jens Meyer)
 * Added D_VAR_SFRPARR type to the kernel.
 * 
 * Revision 4.14  95/02/20  09:56:52  09:56:52  meyer (Jens Meyer)
 * Passed the compilers for HPUX, SUNOS and UCC after the first windows check in.
 * 
 * Revision 4.13  95/02/10  17:19:08  17:19:08  meyer (Jens Meyer)
 * Deleted
 * 
 * Revision 4.12  95/02/01  14:26:51  14:26:51  klotz (W.D. Klotz)
 * WDK: first successfull compile of dbase, api, xdr on WIN16/3.1
 * 
 * Revision 4.11  95/01/03  13:19:29  13:19:29  meyer (Jens Meyer)
 * Repared bug in dev_cmd_query() for version 3!
 * 
 * Revision 4.10  94/12/08  15:24:59  15:24:59  meyer (Jens Meyer)
 * Changed _manager_data in API_xdr and added old version to API_xdr_vers3.
 * 
 * Revision 4.9  94/11/28  17:04:21  17:04:21  meyer (Jens Meyer)
 * Data types for compatibility with library version 3.x
 * 
 * Revision 4.8  94/08/16  16:59:38  16:59:38  meyer (Jens Meyer)
 * Corrected error in ws_xdr.h
 * 
 * Revision 4.7  94/08/16  16:34:33  16:34:33  meyer (Jens Meyer)
 * Added define for MAX_RESOURCE_FIELD_LENGTH to macros.h
 * 
 * Revision 4.6  94/08/12  15:07:49  15:07:49  meyer (Jens Meyer)
 * Added valriable arguments to all API RPC structures.
 * 
 * Revision 4.5  94/07/20  18:15:48  18:15:48  meyer (Jens Meyer)
 * Changed include files in macros.h!
 * 
 * Revision 4.4  94/07/20  08:55:43  08:55:43  meyer (Jens Meyer)
 * All XDR functions with prototypes!
 * 
 * Revision 4.3  94/07/18  18:50:57  18:50:57  meyer (Jens Meyer)
 * Had to change macros.h, because #define must be in the first column!
 * 
 * Revision 4.2  94/07/18  18:22:09  18:22:09  meyer (Jens Meyer)
 * First test with PC macros for the XDR kernel.
 * 
 * Revision 4.1  94/05/02  10:50:51  10:50:51  meyer (Jens Meyer)
 * For Security System without connection count.
 * 
 * Revision 4.0  94/03/14  18:17:36  18:17:36  meyer (Jens Meyer)
 * Library version with Security System.
 * 
 * Revision 3.50  94/03/12  14:36:29  14:36:29  meyer (Jens Meyer)
 * Changed API xdr structures for security.
 * 
 * Revision 3.35  94/03/03  10:52:14  10:52:14  taurel (Emmanuel TAUREL)
 * Added unsigned long array type in the XDRkernel
 * 
 * Revision 3.34  94/03/03  10:29:05  10:29:05  taurel (Emmanuel TAUREL)
 * Added the unsigned long array type in
 * XDR kernel (LC and ET).
 * 
 * Revision 3.33  94/01/12  16:34:29  16:34:29  meyer (Jens Meyer)
 * Global XDR type array for data collector access
 * 
 * Revision 3.31  93/12/02  09:39:04  09:39:04  meyer (Jens Meyer)
 * New release with small XDR data type kernel.
 * 
 * Revision 1.1  93/11/16  17:27:52  17:27:52  meyer (Jens Meyer)
 * Initial revision
 * 

 Copyright (c) 1990 by European Synchrotron Radiation Facility,
		       Grenoble, France

*******************************************************************-*/


#include <dev_xdr.h>
#include <grp_xdr.h>



bool_t
xdr_Frame(xdrs, objp)
	XDR *xdrs;
	Frame *objp;
{
	if (!xdr_double(xdrs, &objp->value)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->output)) {
		return (FALSE);
	}
	if (!xdr_short(xdrs, &objp->pause)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_Frame(objp)
	Frame *objp;
{
        long  length = 0;

	length = length + xdr_length_DevDouble (&objp->value);
        length = length + xdr_length_DevShort (&objp->output);
        length = length + xdr_length_DevShort (&objp->pause);

        return (length);

}



bool_t
xdr_FramePair(xdrs, objp)
	XDR *xdrs;
	FramePair *objp;
{
	if (!xdr_Frame(xdrs, &objp->dead)) {
		return (FALSE);
	}
	if (!xdr_Frame(xdrs, &objp->live)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_FramePair(objp)
	FramePair *objp;
{
        long  length = 0;

        length = length + xdr_length_Frame (&objp->dead);
        length = length + xdr_length_Frame (&objp->live);

        return (length);

}




bool_t
xdr_DevGrpFramePair(xdrs, objp)
	XDR *xdrs;
	DevGrpFramePair *objp;
{
	if (!xdr_u_int(xdrs, &objp->nb_framepair)) {
		return (FALSE);
	}
	if (!xdr_FramePair(xdrs, &objp->framepair)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_DevGrpFramePair(objp)
	DevGrpFramePair *objp;
{
        long  length = 0;

        length = length + xdr_length_DevLong ((long*)&objp->nb_framepair);
        length = length + xdr_length_FramePair (&objp->framepair);

        return (length);

}



bool_t
xdr_DevGrpFramePairArray(xdrs, objp)
	XDR *xdrs;
	DevGrpFramePairArray *objp;
{
	if (!xdr_array(xdrs, (caddr_t *)&objp->sequence, 
	    (u_int *)&objp->length, MAXU_INT, sizeof(DevGrpFramePair), 
	    (xdrproc_t)xdr_DevGrpFramePair)) {
		return (FALSE);
	}
	return (TRUE);
}


long
xdr_length_DevGrpFramePairArray(objp)
	DevGrpFramePairArray *objp;
{
        long    length = 0;

        /*
         *  four bytes for the number of array elements
         */

	length = length + xdr_length_DevLong ((long *)&objp->length);

        /*
         *  now calculate the length of the array
         */

        length = length + (objp->length *
                 xdr_length_DevGrpFramePair(&objp->sequence[0]) );

        return (length);
}
